@@ -36,11 +36,11 @@ typedef enum pu_config_option_t {
   PU_CONFIG_OPTION_CLEANMETHOD,
   PU_CONFIG_OPTION_COLOR,
   PU_CONFIG_OPTION_USESYSLOG,
-  PU_CONFIG_OPTION_USEDELTA,
   PU_CONFIG_OPTION_TOTALDOWNLOAD,
   PU_CONFIG_OPTION_CHECKSPACE,
   PU_CONFIG_OPTION_VERBOSEPKGLISTS,
   PU_CONFIG_OPTION_ILOVECANDY,
+  PU_CONFIG_OPTION_DISABLEDOWNLOADTIMEOUT,
 
   PU_CONFIG_OPTION_SIGLEVEL,
   PU_CONFIG_OPTION_LOCAL_SIGLEVEL,
@@ -88,8 +88,7 @@ typedef struct pu_config_t {
   pu_config_bool_t totaldownload;
   pu_config_bool_t usesyslog;
   pu_config_bool_t verbosepkglists;
-
-  float usedelta;
+  pu_config_bool_t disabledownloadtimeout;
 
   int siglevel;
   int localfilesiglevel;
